@@ -14,7 +14,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.10 2001/07/12 19:58:21 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.12 2001/09/06 19:07:12 shadow Exp $");
 
 #include "../afs/sysincludes.h"
 #include "../afs/afsincludes.h"
@@ -49,11 +49,10 @@ int osi_lookupname(char *aname, uio_seg_t seg, int followlink,
 
     if (!code) {
 	if (nd.dentry->d_inode) {
-	    *dpp = nd.dentry;
+	    *dpp = dget(nd.dentry);
 	    code = 0;
 	}
-	else
-	    path_release(&nd);
+	path_release(&nd);
     }
 #else
     if (seg == AFS_UIOUSER) {
@@ -338,7 +337,9 @@ void osi_clear_inode(struct inode *ip)
 #endif
         printf("afs_put_inode: ino %d (0x%x) has count %d\n", ip->i_ino, ip);
 
+    ObtainWriteLock(&vc->lock, 504);
     afs_InactiveVCache(vc, credp);
+    ReleaseWriteLock(&vc->lock);
 #if defined(AFS_LINUX24_ENV)
     atomic_set(&ip->i_count, 0);
 #else
@@ -378,12 +379,10 @@ void osi_iput(struct inode *ip)
 	if (!ip->i_count)
 #endif
 	    osi_clear_inode(ip);
-        AFS_GUNLOCK();
     }
-    else { 
-        AFS_GUNLOCK();
+    else
 	iput(ip);
-    }
+    AFS_GUNLOCK();
 }
 
 /* check_bad_parent() : Checks if this dentry's vcache is a root vcache
