@@ -189,6 +189,7 @@ struct afs_cbr {
 #define	CNoSUID		    2	    /* 1 if no suid progs can run from this cell */
 #define CHasVolRef	   16	    /* Volumes were referenced in this cell*/
 #define CLinkedCell	   32
+#define CAlias		   64	    /* This cell entry is an alias */
 
 struct cell {
     struct afs_q lruq;			     /* lru q next and prev */
@@ -201,6 +202,7 @@ struct cell {
     short states;			    /* state flags */
     short cellIndex;			    /* relative index number per cell */
     time_t timeout;			    /* data expire time, if non-zero */
+    struct cell *alias;			    /* what this cell is an alias for */
 };
 
 #define	afs_PutCell(cellp, locktype)
@@ -480,36 +482,36 @@ struct SimpleLocks {
 };
 
 /* vcache state bits */
-#define	CStatd	    1		/* has this file ever been stat'd? */
-#define CBackup	    2		/* file is on a backup volume */
-#define	CRO	    4		/* is it on a read-only volume */
-#define	CMValid	    8		/* is the mount point info valid? */
-#define	CCore	    0x10	/* storing a core file, needed since we don't get an open */
-#define CDirty      0x20        /* file has been modified since first open (... O_RDWR) */
-#define	CSafeStore  0x40	/* close must wait for store to finish (should be in fd) */
-#define	CMAPPED	    0x80	/* Mapped files; primarily used by SunOS 4.0.x */
-#define	CNSHARE	    0x100	/* support O_NSHARE semantics */
-#define	CLied	    0x200
-#define	CTruth	    0x400
+#define CStatd		0x00000001	/* has this file ever been stat'd? */
+#define CBackup		0x00000002	/* file is on a backup volume */
+#define CRO		0x00000004	/* is it on a read-only volume */
+#define CMValid		0x00000008	/* is the mount point info valid? */
+#define CCore		0x00000010	/* storing a core file, needed since we don't get an open */
+#define CDirty		0x00000020	/* file has been modified since first open (... O_RDWR) */
+#define CSafeStore	0x00000040	/* close must wait for store to finish (should be in fd) */
+#define CMAPPED		0x00000080	/* Mapped files; primarily used by SunOS 4.0.x */
+#define CNSHARE		0x00000100	/* support O_NSHARE semantics */
+#define CLied		0x00000200
+#define CTruth		0x00000400
 #ifdef	AFS_OSF_ENV
-#define	CWired	    0x800	/* OSF hack only */
+#define CWired		0x00000800	/* OSF hack only */
 #else
-#define	CWRITE_IGN  0x800	/* Next OS hack only */
+#define CWRITE_IGN	0x00000800	/* Next OS hack only */
 #endif
-#define	CUnique	    0x1000	/* vc's uniquifier - latest unifiquier for fid */
-#define	CForeign    0x2000	/* this is a non-afs vcache */
-#define CHasPages   0x4000
-#define CUnlinked   0x10000
-#define CBulkStat   0x20000	/* loaded by a bulk stat, and not ref'd since */
-#define CUnlinkedDel  0x40000
-#define CVFlushed   0x80000
-#define	CCore1	    0x100000	/* osf1 core file; not same as CCore above */
-#define CWritingUFS 0x200000	/* to detect vm deadlock - used by sgi */
-#define CCreating   0x400000	/* avoid needless store after open truncate */
-#define CPageHog    0x800000	/* AIX - dumping large cores is a page hog. */
-#define CDCLock	    0x200000	/* Vnode lock held over call to GetDownD */
-#define CBulkFetching 0x4000000 /* stats are being fetched by bulk stat */
-#define CExtendedFile 0x8000000 /* extended file via ftruncate call. */
+#define CUnique		0x00001000	/* vc's uniquifier - latest unifiquier for fid */
+#define CForeign	0x00002000	/* this is a non-afs vcache */
+#define CHasPages	0x00004000
+#define CUnlinked	0x00010000
+#define CBulkStat	0x00020000	/* loaded by a bulk stat, and not ref'd since */
+#define CUnlinkedDel	0x00040000
+#define CVFlushed	0x00080000
+#define CCore1		0x00100000	/* osf1 core file; not same as CCore above */
+#define CWritingUFS	0x00200000	/* to detect vm deadlock - used by sgi */
+#define CCreating	0x00400000	/* avoid needless store after open truncate */
+#define CPageHog	0x00800000	/* AIX - dumping large cores is a page hog. */
+#define CDCLock		0x02000000	/* Vnode lock held over call to GetDownD */
+#define CBulkFetching	0x04000000	/* stats are being fetched by bulk stat */
+#define CExtendedFile	0x08000000	/* extended file via ftruncate call. */
 
 /* vcache vstate bits */
 #define VRevokeWait   0x1
@@ -522,6 +524,18 @@ struct SimpleLocks {
 #define vrefCount   v.v_usecount
 #endif /* AFS_FBSD_ENV */
 
+#ifdef AFS_LINUX24_ENV
+#define VREFCOUNT(v)		atomic_read(&((vnode_t *) v)->v_count)
+#define VREFCOUNT_SET(v, c)	atomic_set(&((vnode_t *) v)->v_count, c)
+#define VREFCOUNT_DEC(v)	atomic_dec(&((vnode_t *) v)->v_count)
+#define VREFCOUNT_INC(v)	atomic_inc(&((vnode_t *) v)->v_count)
+#else
+#define VREFCOUNT(v)		((v)->vrefCount)
+#define VREFCOUNT_SET(v, c)	(v)->vrefCount = c;
+#define VREFCOUNT_DEC(v)	(v)->vrefCount--;
+#define VREFCOUNT_INC(v)	(v)->vrefCount++;
+#endif
+
 #define	AFS_MAXDV   0x7fffffff	    /* largest dataversion number */
 #define	AFS_NOTRUNC 0x7fffffff	    /* largest dataversion number */
 
@@ -946,6 +960,7 @@ extern struct brequest afs_brs[NBRS];		/* request structures */
 
 extern struct cell	    *afs_GetCell();
 extern struct cell	    *afs_GetCellByName();
+extern struct cell	    *afs_GetCellByIndex();
 extern struct unixuser	    *afs_GetUser();
 extern struct volume	    *afs_GetVolume();
 extern struct volume	    *afs_GetVolumeByName();
@@ -978,6 +993,17 @@ extern void afs_shutdown();
 /* afs_osifile.c */
 extern void shutdown_osifile();
 
+/* afs_dynroot.c */
+extern int afs_IsDynrootFid();
+extern void afs_GetDynrootFid();
+extern int afs_IsDynroot();
+extern void afs_RefreshDynroot();
+extern void afs_GetDynroot();
+extern void afs_PutDynroot();
+extern int afs_DynrootNewVnode();
+extern int afs_SetDynrootEnable();
+extern int afs_GetDynrootEnable();
+
 
 /* Performance hack - we could replace VerifyVCache2 with the appropriate
  * GetVCache incantation, and could eliminate even this code from afs_UFSRead 
@@ -1036,6 +1062,7 @@ extern int afs_CacheTooFull;
  * afs_GetDownD wakes those processes once the cache is 95% full
  * (CM_CACHESIZEDRAINEDPCT).
  */
+extern void afs_MaybeWakeupTruncateDaemon();
 extern void afs_CacheTruncateDaemon();
 extern int afs_WaitForCacheDrain;
 #define CM_MAXDISCARDEDCHUNKS	16      /* # of chunks */
@@ -1051,19 +1078,6 @@ extern int afs_WaitForCacheDrain;
      afs_freeDCCount - afs_discardDCCount < \
 	((100-CM_DCACHECOUNTFREEPCT)*afs_cacheFiles)/100)
 
-#define	afs_MaybeWakeupTruncateDaemon()	\
-    do { \
-	if (!afs_CacheTooFull && afs_CacheIsTooFull()) { \
-	    afs_CacheTooFull = 1; \
-            if (!afs_TruncateDaemonRunning) { \
-		afs_osi_Wakeup((char *)afs_CacheTruncateDaemon); \
-	    } \
-	} else if (!afs_TruncateDaemonRunning && \
-		   afs_blocksDiscarded > CM_MAXDISCARDEDCHUNKS) { \
-	    afs_osi_Wakeup((char *)afs_CacheTruncateDaemon); \
-	} \
-    } while (0)
-
 /* Handy max length of a numeric string. */
 #define	CVBS	12  /* max afs_int32 is 2^32 ~ 4*10^9, +1 for NULL, +luck */
 
