@@ -49,7 +49,7 @@ Generic install command.  Options are:
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/pinstall/install.c,v 1.8 2001/07/12 19:58:53 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/pinstall/install.c,v 1.9.2.2 2001/10/13 04:21:46 shadow Exp $");
 
 #include <stdio.h>
 #include <pwd.h>
@@ -81,6 +81,7 @@ RCSID("$Header: /cvs/openafs/src/pinstall/install.c,v 1.8 2001/07/12 19:58:53 sh
 #include <unistd.h>
 #include <string.h>
 #include <sys/wait.h>
+#include <stdlib.h>
 
 struct stat istat, ostat;
 
@@ -89,15 +90,11 @@ extern int sys_nerr;
 #if !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
 extern char *sys_errlist[];
 #endif
-#if	defined(AFS_AIX_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DECOSF_ENV) || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if	defined(AFS_AIX_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DECOSF_ENV) || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 extern struct passwd *getpwnam();
 int stripcalled = 0;
 #endif
 
-#ifndef rindex
-extern char *rindex();   /* this should always be defined, shouldn't it? */
-#endif
-
 #if defined(AFS_HPUX_ENV) && !defined(AFS_HPUX102_ENV)
 utimes(file,tvp)
 char *file;
@@ -118,7 +115,7 @@ static char *strrpbrk (s, set)
     char sets[256];
     int  i;
 
-    bzero (sets, sizeof(sets));
+    memset(sets, 0, sizeof(sets));
     while (*set) sets[(int) *set++] = 1;
     i = strlen (s);
     while (i > 0) if (sets[(int)s[--i]]) return &s[i];
@@ -139,7 +136,7 @@ char *ErrorString(aerrno)
 int
 stripName(aname)
     char *aname;
-    {if (rindex(aname, '.') == 0) return 1;
+    {if (strrchr(aname, '.') == 0) return 1;
     else return 0;
     }
 
@@ -156,7 +153,7 @@ atoo(astr)
     return value;
     }
 
-#if	defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DECOSF_ENV) || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV)
+#if	defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DECOSF_ENV) || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_OBSD_ENV)
 /*
  * Implementation lifted from that for AIX 3.1, since there didn't seem to be any
  * reason why it wouldn't work.
@@ -208,6 +205,7 @@ char *iname, *oname; {
 		return -1;
 	}
 
+#ifndef AFS_OBSD_ENV
 	/*
 	 * done the copy, now strip if desired.
 	 */
@@ -238,6 +236,7 @@ char *iname, *oname; {
 			return -1;
 		}
 	}
+#endif
 
 	return status;
 }
@@ -477,7 +476,7 @@ main (argc, argv)
 #endif /* AFS_HPUX_ENV */
     char pnametmp[1024];
     int pnamelen;
-#if defined (AFS_AIX_ENV) || defined(AFS_FBSD_ENV)
+#if defined (AFS_AIX_ENV) || defined(AFS_XBSD_ENV)
     afs_int32 newcode;
     static char diskBuffer[BUFSIZE];	/* must be static to avoid compiler bugs for large stuff */
 #endif
@@ -642,7 +641,7 @@ main (argc, argv)
 
     for (i=0;i<fptr;i++)
 	{/* figure out name to put as entry name for file */
-	tp = rindex(fnames[i], '/');
+	tp = strrchr(fnames[i], '/');
 	if (tp) newNames[i] = tp+1;
 	else newNames[i] = fnames[i];
 	}
@@ -688,7 +687,7 @@ main (argc, argv)
 		continue;
 	    }
 	}
-#if	defined(AFS_AIX_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DECOSF_ENV) || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV)
+#if	defined(AFS_AIX_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DECOSF_ENV) || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_OBSD_ENV)
 	stripcalled = 0;
 	if (strip == 1 ||
 	    ((strip == -1 && ((istat.st_mode & 0111) == 0111) && stripName(newNames[i])) && AIXobject(fnames[i])))
