@@ -41,7 +41,7 @@
 #define MAX(a,b)  ((a)>(b)?(a):(b))
 #endif
 #else /* AFS_NT40_ENV */
-#if !defined(AFS_DARWIN_ENV) && !defined(AFS_USR_DARWIN_ENV) && !defined(AFS_FBSD_ENV) && !defined(AFS_USR_FBSD_ENV)
+#if !defined(AFS_DARWIN_ENV) && !defined(AFS_USR_DARWIN_ENV) && !defined(AFS_XBSD_ENV) && !defined(AFS_USR_FBSD_ENV)
 #include <sys/sysmacros.h>      /* MIN, MAX on Solaris */
 #endif
 #include <sys/param.h>          /* MIN, MAX elsewhere */
@@ -151,7 +151,6 @@
 				     * the receiver should be greater than
                                      * this one, rather than a resend of an
 				     * earlier sequence number */
-#define	RX_FREE_PACKET		16	/* Unallocated to a call */
 #define RX_SLOW_START_OK	32  /* Set this flag in an ack packet to
 				     * inform the sender that slow start is
 				     * supported by the receiver. */
@@ -164,6 +163,14 @@
 #define	RX_PRESET_FLAGS		(RX_CLIENT_INITIATED | RX_LAST_PACKET)
 
 
+/*
+ * Flags for the packet structure itself, housekeeping for the
+ * most part.  These live in rx_packet->flags.
+ */
+#define	RX_PKTFLAG_ACKED	0x01
+#define	RX_PKTFLAG_FREE		0x02
+
+
 /* The rx part of the header of a packet, in host form */
 struct rx_header {
     afs_uint32 epoch;	/* Start time of client process */
@@ -245,7 +252,7 @@ struct rx_packet {
     unsigned int niovecs;
     struct iovec wirevec[RX_MAXWVECS+1];       /* the new form of the packet */
     
-    u_char acked;	/* This packet has been *tentatively* acknowledged */
+    u_char flags;		    /* Flags for local state of this packet */
     u_char backoff;                 /* for multiple re-sends */
     u_short length;		    /* Data length */
     /* NT port relies on the fact that the next two are physically adjacent.
@@ -313,13 +320,13 @@ struct rx_packet *rxi_SplitJumboPacket();
 #define rx_packetwrite(p, off, len, in)               \
   ( (off) + (len) > (p)->wirevec[1].iov_len ?         \
     rx_SlowWritePacket(p, off, len, (char*)(in)) :             \
-    ((bcopy((char *)(in), (char*)((p)->wirevec[1].iov_base)+(off), (len))),0))
+    ((memcpy((char*)((p)->wirevec[1].iov_base)+(off), (char *)(in), (len))),0))
 
 /* copy data from an RX packet */
 #define rx_packetread(p, off, len, out)               \
   ( (off) + (len) > (p)->wirevec[1].iov_len ?         \
     rx_SlowReadPacket(p, off, len, (char*)out) :             \
-    ((bcopy((char*)((p)->wirevec[1].iov_base)+(off), (char *)(out), len)),0))
+    ((memcpy((char *)(out), (char*)((p)->wirevec[1].iov_base)+(off), len)),0))
 
 #define rx_computelen(p,l) { register int i; \
    for (l=0, i=1; i < p->niovecs; i++ ) l += p->wirevec[i].iov_len; }
