@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/ubik/beacon.c,v 1.8 2001/07/12 19:59:18 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/ubik/beacon.c,v 1.9.2.2 2001/10/13 04:21:56 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -25,6 +25,13 @@ RCSID("$Header: /cvs/openafs/src/ubik/beacon.c,v 1.8 2001/07/12 19:59:18 shadow
 #endif
 #include <errno.h>
 #include <lock.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <rx/rx_multi.h>
@@ -50,6 +57,7 @@ int (*ubik_CRXSecurityProc)();
 char *ubik_CRXSecurityRock;
 afs_int32 ubikSecIndex;
 struct rx_securityClass     *ubikSecClass;
+static verifyInterfaceAddress();
 
 
 /* Module responsible for both deciding if we're currently the sync site,
@@ -170,7 +178,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
     struct ubik_server *magicServer;
 
     /* verify that the addresses passed in are correct */
-    if (code = verifyInterfaceAddress(&ame, info, aservers))
+    if ((code = verifyInterfaceAddress(&ame, info, aservers)))
 	return code;
 
     /* get the security index to use, if we can */
@@ -201,7 +209,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
         for (i = 0; i < info->numServers; i++) {
             if (i == me) continue;
 	    ts = (struct ubik_server *) malloc(sizeof(struct ubik_server));
-	    bzero(ts, sizeof(struct ubik_server));
+	    memset(ts, 0, sizeof(struct ubik_server));
 	    ts->next = ubik_servers;
 	    ubik_servers = ts;
             ts->addr[0] = info->hostAddr[i].sin_addr.s_addr;
@@ -229,10 +237,10 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
 	}
     } else {
         i = 0;
-        while (servAddr = *aservers++) {
+        while ((servAddr = *aservers++)) {
 	    if (i >= MAXSERVERS) return UNHOSTS;	    /* too many hosts */
 	    ts = (struct ubik_server *) malloc(sizeof(struct ubik_server));
-	    bzero(ts, sizeof(struct ubik_server));
+	    memset(ts, 0, sizeof(struct ubik_server));
 	    ts->next = ubik_servers;
 	    ubik_servers = ts;
 	    ts->addr[0] = servAddr;	/* primary address in  net byte order */
@@ -447,7 +455,7 @@ static verifyInterfaceAddress(ame, info, aservers)
     afs_uint32 aservers[]; 	/* list of all possible server addresses */
 {
     afs_uint32	myAddr[UBIK_MAX_INTERFACE_ADDR], *servList, tmpAddr;
-    int 	count, index, found, i, j, totalServers, start, end;
+    int 	count, found, i, j, totalServers, start, end;
 
     if (info)
         totalServers = info->numServers;
@@ -574,7 +582,7 @@ int
 updateUbikNetworkAddress(ubik_host)
 afs_uint32 ubik_host[UBIK_MAX_INTERFACE_ADDR];
 {
-    int			j, count, found, index, code = 0;
+    int			j, count, code = 0;
     UbikInterfaceAddr   inAddr, outAddr;
     struct rx_connection *conns[MAXSERVERS];
     struct ubik_server 	*ts, *server[MAXSERVERS];
